Intended as entry point to start up a shiny app, the generic function
serve() can be dispatched either on a single block (mainly for previewing
purposes during block development) or an entire board
Usage
serve(x, ...)
# S3 method for class 'block'
serve(x, id = "block", ..., data = list())
# S3 method for class 'board'
serve(
x,
id = rand_names(),
plugins = blockr_app_plugins,
options = blockr_app_options,
...
)
blockr_app_plugins(x)
custom_plugins(x)
blockr_app_options(x)
custom_options(x)
blockr_app_ui(id, x, ...)
blockr_app_server(id, x, ...)
get_serve_obj(id = NULL)
blockr_test_exports(x, rv, ...)Arguments
- x
Object
- ...
Generic consistency
- id
Board namespace ID
- data
Data inputs
- plugins
Board plugins
- options
Board options
- rv
Board
shiny::reactiveValues()
Value
The generic serve() is expected to return the result of a call to
shiny::shinyApp().