Intended as entry point to start up a shiny app, the generic function
serve() can be dispatched either on a single block (mainly for previewing
purposes during block development) or an entire board
serve(x, ...)# S3 method for block
serve(x, id = "block", ..., data = list())
# S3 method for board
serve(
x,
id = rand_names(),
plugins = blockr_app_plugins,
options = blockr_app_options,
loader = local_loader(),
...
)
blockr_app_plugins(x)
custom_plugins(x)
blockr_app_options(x)
custom_options(x)
blockr_app_ui(id, x, ...)
blockr_app_server(id, x, ...)
blockr_test_exports(x, rv, ...)
The generic serve() is expected to return the result of a call to
shiny::shinyApp().
Object
Generic consistency
Board namespace ID
Data inputs
Board plugins
Board options
A board_loader() resolving the board to build for each
request; defaults to local_loader(), the in-process save/restore handoff
Board shiny::reactiveValues()